create_path_to_file: Creates a full file path by taking name components sans...

Description Usage Arguments

View source: R/create_path_to_file.R

Description

Creates a full file path by taking name components sans punctuation

Usage

1
create_path_to_file(path_folder, basename, file_extension = NULL)

Arguments

path_folder

path to destination folder including forward slashes

basename

basename of file without file extension

file_extension

file extension


patelm9/mirroR documentation built on Feb. 12, 2020, 2:41 p.m.