Description Usage Arguments
View source: R/load_robj.R
Loads an R object based on name if a corresponding R data file is in the working directory
1
load_robj(robj)
robj
R object
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.