rm_if_exists: Removes R objects in the global environment if R object...

Description Usage Arguments

View source: R/rm_if_exists.R

Description

Removes R objects in the global environment if R object doesn't exist

Usage

1
rm_if_exists(r_object)

Arguments

r_object

single R object that is removed if it is present in the environment


patelm9/mirroR documentation built on Feb. 12, 2020, 2:41 p.m.